==> five.grok-1.0a2.tar.gz: five.grok-1.0a2/src/five/grok/__init__.py <==
#############################################################################
#
# Copyright (c) 2008 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

from grokcore.component import *
from grokcore.security import *
from grokcore.view import *
from grokcore.viewlet import *
from grokcore.formlib import *

from five.grok.components import Model, Container
from five.grok.components import View, Form, AddForm
from five.grok.components import EditForm, DisplayForm
from five.grok.components import ViewletManager, Viewlet
from five.grok.formlib import AutoFields

# Temporary import explicitly path from grokcore.view (it was missing
# in its API interface)
from grokcore.view import path

# Override the one from grokcore.view so that we get Zope 2 semantics
from five.grok.components import ZopeTwoPageTemplate as PageTemplate
from five.grok.components import ZopeTwoPageTemplateFile as PageTemplateFile

# Override DirectoryResource to use Zope 2 one
from five.grok.components import ZopeTwoDirectoryResource as DirectoryResource

==> five.grok-1.1.tar.gz: five.grok-1.1/src/five/grok/__init__.py <==
#############################################################################
#
# Copyright (c) 2008 Zope Corporation and Contributors.
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#
##############################################################################

from grokcore.component import *
from grokcore.annotation import *
from grokcore.security import *
from grokcore.site import *
from grokcore.view import *
from grokcore.viewlet import *
from grokcore.formlib import *

from five.grok.components import Model, Container, Site, LocalUtility
from five.grok.components import Form, AddForm
from five.grok.components import EditForm, DisplayForm
from five.grok.components import View, ViewletManager
from five.grok.formlib import AutoFields

# backwards compatibility. Probably not needed by many, but just in case.
# please start using grokcore.view.View again.
CodeView = View

# Override the one from grokcore.view so that we get Zope 2 semantics
from five.grok.components import ZopeTwoPageTemplate as PageTemplate
from five.grok.components import ZopeTwoPageTemplateFile as PageTemplateFile

# Override DirectoryResource to use Zope 2 one
from five.grok.components import ZopeTwoDirectoryResource as DirectoryResource

# Only export public API
from five.grok.interfaces import IFiveGrokAPI
__all__ = list(IFiveGrokAPI)
